
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------
--                                                                            --
--  COPYRIGHT (C) 2005, DILLON ENGINEERING, INC.                              --
--                                                                            --
--  Dillon Engineering, Inc.       http://www.dilloneng.com                   --
--  3925 West 50th St.             info@dilloneng.com                         --
--  Suite 202                      952-836-2413                               --
--  Edina, MN 55424                                                           --
--                                                                            --
--    Name        : de_float_pkd                                              --
--    Rev         : $Id$
--                                                                            --
--    Description : Package file de_float library build.                      --
--                                                                            --
--------------------------------------------------------------------------------
--------------------------------------------------------------------------------

-------------------------- Library Declarations --------------------------------
library ieee;
use ieee.std_logic_1164.all;

package de_fplic_pkg is
  constant int_width  : integer := 24;
  constant exp_width  : integer := 6;
  constant man_width  : integer := 16;
  constant full_width : integer := exp_width+man_width+1;

  component comp_add_FpAddSub_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_b                         : in    std_logic_vector(full_width-1 downto 0);
          port_sp_out                    : out   std_logic_vector(3 downto 0) := (others => '0');
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_add_FpAddSub_0;

  component comp_sub_FpAddSub_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_b                         : in    std_logic_vector(full_width-1 downto 0);
          port_sp_out                    : out   std_logic_vector(3 downto 0) := (others => '0');
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_sub_FpAddSub_0;

  component comp_mult_FpMult_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_b                         : in    std_logic_vector(full_width-1 downto 0);
          port_sp_out                    : out   std_logic_vector(3 downto 0) := (others => '0');
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_mult_FpMult_0;

  component comp_div_FpDiv_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_b                         : in    std_logic_vector(full_width-1 downto 0);
          port_sp_out                    : out   std_logic_vector(3 downto 0) := (others => '0');
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_div_FpDiv_0;

  component comp_sqrt_FpSqrt_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_sp_out                    : out   std_logic_vector(3 downto 0) := (others => '0');
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_sqrt_FpSqrt_0;

  component comp_rcp_FpRcp_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_sp_out                    : out   std_logic_vector(3 downto 0) := (others => '0');
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_rcp_FpRcp_0;

  component comp_cmp_FpCmp_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_b                         : in    std_logic_vector(full_width-1 downto 0);
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_er                        : out   std_logic := '0';
          port_eq                        : out   std_logic := '0';
          port_gt                        : out   std_logic := '0';
          port_lt                  :       out   std_logic := '0');
  end component comp_cmp_FpCmp_0;

  component comp_i2f_Int2Fp_0 is
    port( port_a                         : in    std_logic_vector(int_width-1 downto 0);
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_x                         : out   std_logic_vector(full_width-1 downto 0) := (others => '0')  );
  end component comp_i2f_Int2Fp_0;

  component comp_f2i_Fp2Int_0 is
    port( port_a                         : in    std_logic_vector(full_width-1 downto 0);
          port_sync_in                   : in    std_logic;
          port_clk                       : in    std_logic;
          port_sync_out                  : out   std_logic := '0';
          port_oflow                     : out   std_logic := '0';
          port_x                         : out   std_logic_vector(int_width-1 downto 0) := (others => '0')  );
  end component comp_f2i_Fp2Int_0;

  component comp_split_FpSplit_0 is
    port( port_fp                        : in    std_logic_vector(full_width-1 downto 0);
          port_man                       : out   std_logic_vector(man_width-1 downto 0) := (others => '0');
          port_exp                       : out   std_logic_vector(exp_width-1 downto 0) := (others => '0');
          port_sign                      : out   std_logic := '0'  );
  end component comp_split_FpSplit_0;

  component comp_cat_FpCat_0 is
    port( port_fp                        : out   std_logic_vector(full_width-1 downto 0) := (others => '0');
          port_man                       : in    std_logic_vector(man_width-1 downto 0);
          port_exp                       : in    std_logic_vector(exp_width-1 downto 0);
          port_sign                      : in    std_logic  );
  end component comp_cat_FpCat_0;

end package de_fplic_pkg;